@@ -67,7 +67,6 @@ const music_player_t pm_player =
 
 #else // HAVE_LIBPORTMIDI
 
-#include <math.h>
 #include <portmidi.h>
 #include <porttime.h>
 #include <stdio.h>
@@ -394,7 +393,7 @@ static void pm_setvolume (int v)
     return;
 
   pm_volume = v;
-  volume_scale = sqrtf((float)pm_volume / 15);
+  volume_scale = pm_volume / 15.0f;
   update_volume();
 }
 
@@ -651,6 +650,7 @@ static void pm_render (void *vdest, unsigned bufflen)
               {
                 writeevent (when, 0xB0, i, 0x7B, 0x00); // all notes off
                 writeevent (when, 0xB0, i, 0x79, 0x00); // reset all controllers
+                write_volume (when, i, DEFAULT_VOLUME); // reset volume
               }
               continue;
             }
