@@ -56,6 +56,10 @@
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#ifdef HAVE_GETPWUID
+#include <sys/types.h>
+#include <pwd.h>
+#endif
 #endif
 
 #ifdef _MSC_VER
@@ -312,7 +316,17 @@ const char *I_ConfigDir(void)
 
   if (!base)
   {
-    char *home = M_getenv("HOME");
+    const char *home = M_getenv("HOME");
+    if (!home)
+    {
+#ifdef HAVE_GETPWUID
+      struct passwd *user_info = getpwuid(getuid());
+      if (user_info != NULL)
+        home = user_info->pw_dir;
+      else
+#endif
+        home = "/";
+    }
 
     // First, try legacy directory.
     base = dsda_ConcatDir(home, ".dsda-doom");
@@ -335,7 +349,7 @@ const char *I_ConfigDir(void)
 #endif
     }
 
-    M_MakeDir(base, true); // Make sure it exists
+    M_MakeDir(base, false);
   }
 
   return base;
