@@ -57,6 +57,7 @@
 #include "m_misc.h"
 #include "m_bbox.h"
 #include "d_main.h"
+#include "m_menu.h"
 
 #include "dsda/id_list.h"
 #include "dsda/input.h"
@@ -160,6 +161,7 @@ static highlight_t highlight;
 static int map_blinking_locks;
 static int map_secret_after;
 static int map_grid_size;
+static int map_pan_speed;
 static int map_scroll_speed;
 static int map_wheel_zoom;
 int map_textured;
@@ -174,13 +176,15 @@ static map_things_appearance_t map_things_appearance;
 #define INITSCALEMTOF (.2*FRACUNIT)
 // how much the automap moves window per tic in frame-buffer coordinates
 // moves 140 pixels in 1 second
-#define F_PANINC  (dsda_InputActive(dsda_input_speed) ? map_scroll_speed * 2 : map_scroll_speed)
+#define F_SPEED  (dsda_InputActive(dsda_input_speed) ? !dsda_AutoRun() : dsda_AutoRun())
+#define F_PANINC  (F_SPEED ? map_pan_speed * 2 : map_pan_speed)
+#define F_ZOOMINC  (F_SPEED ? map_scroll_speed * 2 : map_scroll_speed)
 // how much zoom-in per tic
 // goes to 2x in 1 second
-#define M_ZOOMIN        ((int) ((float)FRACUNIT * (1.00f + F_PANINC / 200.0f)))
+#define M_ZOOMIN        ((int) ((float)FRACUNIT * (1.00f + F_ZOOMINC / 200.0f)))
 // how much zoom-out per tic
 // pulls out to 0.5x in 1 second
-#define M_ZOOMOUT       ((int) ((float)FRACUNIT / (1.00f + F_PANINC / 200.0f)))
+#define M_ZOOMOUT       ((int) ((float)FRACUNIT / (1.00f + F_ZOOMINC / 200.0f)))
 
 #define PLAYERRADIUS    (16*(1<<MAPBITS)) // e6y
 
@@ -616,7 +620,7 @@ void AM_SetPosition(void)
     f_x = f_y = 0;
     f_w = SCREENWIDTH;
 
-    if (automap_overlay)
+    if (automap_overlay > 0)
     {
       f_h = viewheight;
     }
@@ -732,6 +736,7 @@ void AM_InitParams(void)
 {
   map_blinking_locks = dsda_IntConfig(dsda_config_map_blinking_locks);
   map_secret_after = dsda_IntConfig(dsda_config_map_secret_after);
+  map_pan_speed = dsda_IntConfig(dsda_config_map_pan_speed);
   map_scroll_speed = dsda_IntConfig(dsda_config_map_scroll_speed);
   map_grid_size = dsda_IntConfig(dsda_config_map_grid_size);
   map_wheel_zoom = dsda_IntConfig(dsda_config_map_wheel_zoom);
@@ -1004,6 +1009,18 @@ dboolean AM_Responder
 {
   static int bigstate=0;
 
+  if (dsda_InputActivated(dsda_input_map_overlay) && (automap_input || dsda_ShowMinimap()))
+  {
+    dsda_CycleConfig(dsda_config_automap_overlay, true);
+    dsda_AddMessage(automap_overlay == 0 ? s_AMSTR_OVERLAYOFF :
+                    automap_overlay == 1 ? s_AMSTR_OVERLAYON :
+                    "Overlay Mode Dark");
+    AM_SetPosition();
+    AM_activateNewScale();
+
+    return true;
+  }
+
   if (!automap_input)
   {
     if (dsda_InputActivated(dsda_input_map))
@@ -1145,14 +1162,6 @@ dboolean AM_Responder
 
     return true;
   }
-  else if (dsda_InputActivated(dsda_input_map_overlay))
-  {
-    dsda_ToggleConfig(dsda_config_automap_overlay, true);
-    AM_SetPosition();
-    AM_activateNewScale();
-
-    return true;
-  }
   else if (dsda_InputActivated(dsda_input_map_textured))
   {
     dsda_ToggleConfig(dsda_config_map_textured, true);
@@ -1246,21 +1255,21 @@ static void AM_changeWindowScale(void)
 {
   if (movement_smooth)
   {
-    float f_paninc = (float)F_PANINC / (float)FRACUNIT * (float)tic_vars.frac;
+    float f_zoominc = (float)F_ZOOMINC / (float)FRACUNIT * (float)tic_vars.frac;
 
-    if (f_paninc < 0.01f)
-      f_paninc = 0.01f;
+    if (f_zoominc < 0.01f)
+      f_zoominc = 0.01f;
 
     scale_mtof = prev_scale_mtof;
     if (curr_mtof_zoommul == M_ZOOMIN)
     {
-      mtof_zoommul = ((int) ((float)FRACUNIT * (1.00f + f_paninc / 200.0f)));
-      ftom_zoommul = ((int) ((float)FRACUNIT / (1.00f + f_paninc / 200.0f)));
+      mtof_zoommul = ((int) ((float)FRACUNIT * (1.00f + f_zoominc / 200.0f)));
+      ftom_zoommul = ((int) ((float)FRACUNIT / (1.00f + f_zoominc / 200.0f)));
     }
     if (curr_mtof_zoommul == M_ZOOMOUT)
     {
-      mtof_zoommul = ((int) ((float)FRACUNIT / (1.00f + f_paninc / 200.0f)));
-      ftom_zoommul = ((int) ((float)FRACUNIT * (1.00f + f_paninc / 200.0f)));
+      mtof_zoommul = ((int) ((float)FRACUNIT / (1.00f + f_zoominc / 200.0f)));
+      ftom_zoommul = ((int) ((float)FRACUNIT * (1.00f + f_zoominc / 200.0f)));
     }
   }
 
@@ -2769,6 +2778,9 @@ void AM_Drawer (dboolean minimap)
   if (!automap_active && !minimap)
     return;
 
+  if (automap_active && automap_overlay == 2 && minimap)
+    return;
+
   V_BeginAutomapDraw();
 
   if (automap_follow)
@@ -2792,6 +2804,8 @@ void AM_Drawer (dboolean minimap)
 
   if (!automap_overlay) // cph - If not overlay mode, clear background for the automap
     V_FillRect(FB, f_x, f_y, f_w, f_h, (byte)mapcolor_p->back); //jff 1/5/98 background default color
+  if (automap_overlay == 2 && !M_MenuIsShaded())
+    V_DrawShaded(FB, f_x, f_y, f_w, f_h, FULLSHADE);
 
   if (map_textured)
   {
