@@ -109,6 +109,10 @@ typedef enum {
 // SCREENWIDTH and SCREENHEIGHT define the visible size
 extern int SCREENWIDTH;
 extern int SCREENHEIGHT;
+// ACTUALHEIGHT is the actual height of the resolution
+// If the resolution is 200p or 400p, aspect ratio correction
+// should be applied, making this value 240 or 480
+extern int ACTUALHEIGHT;
 // SCREENPITCH is the size of one line in the buffer and
 // can be bigger than the SCREENWIDTH depending on the size
 // of one pixel (8, 16 or 32 bit) and the padding at the
@@ -396,6 +400,8 @@ typedef enum {
 #define KEYD_MOUSE3     (0x80 + 0x62)
 #define KEYD_MWHEELUP   (0x80 + 0x6b)
 #define KEYD_MWHEELDOWN (0x80 + 0x6c)
+#define KEYD_MWHEELLEFT (0X80 + 0X6d)
+#define KEYD_MWHEELRIGHT (0X80 + 0X6e)
 
 // phares 3/20/98:
 //
