@@ -197,7 +197,8 @@ extern int automap_follow;
 extern int automap_grid;
 
 #define automap_on (automap_active && !automap_overlay)
-#define automap_off (!automap_on)
+#define automap_off (!automap_active && automap_overlay > 0)
+#define automap_stbar (automap_active && R_StatusBarVisible())
 #define automap_input (automap_active)
 #define automap_hud (automap_active && !automap_overlay)
 
