@@ -70,7 +70,7 @@
 #define CF_ALWAYS (CF_DEMO|CF_STRICT)
 
 typedef struct console_entry_s {
-  char text[CONSOLE_ENTRY_SIZE + 1];
+  char text[CONSOLE_ENTRY_SIZE];
   struct console_entry_s* prev;
   struct console_entry_s* next;
 } console_entry_t;
@@ -78,7 +78,7 @@ typedef struct console_entry_s {
 static console_entry_t* console_history_head;
 static console_entry_t* console_entry;
 static int console_entry_index;
-static char console_message[CONSOLE_ENTRY_SIZE + 3] = { ' ', ' ' };
+static char console_message[CONSOLE_ENTRY_SIZE + 2] = { ' ', ' ' };
 static char* console_message_entry = console_message + 2;
 static hu_textline_t hu_console_prompt;
 static hu_textline_t hu_console_message;
@@ -236,6 +236,12 @@ static dboolean console_PlayerSetHealth(const char* command, const char* args) {
   return false;
 }
 
+static dboolean console_PlayerKill(const char* command, const char* args) {
+  P_DamageMobj(target_player.mo, NULL, NULL, 10000);
+
+  return true;
+}
+
 static dboolean console_PlayerSetArmor(const char* command, const char* args) {
   int arg_count;
   int armorpoints, armortype;
@@ -972,6 +978,18 @@ static dboolean console_BruteForceStart(const char* command, const char* args) {
 
         dsda_AddMiscBruteForceCondition(dsda_bf_have_item, attr_i);
       }
+      else if (sscanf(conditions[i], " lack %3[a-zA-Z]", attr_s) == 1) {
+        int attr_i;
+
+        for (attr_i = 0; attr_i < dsda_bf_item_max; ++attr_i)
+          if (!strcmp(attr_s, dsda_bf_item_names[attr_i]))
+            break;
+
+        if (attr_i == dsda_bf_item_max)
+          return false;
+
+        dsda_AddMiscBruteForceCondition(dsda_bf_lack_item, attr_i);
+      }
       else if (sscanf(conditions[i], " %3[a-zA-Z] %4[a-zA-Z><!=] %i", attr_s, oper_s, &value) == 3) {
         int attr_i, oper_i;
 
@@ -2266,6 +2284,7 @@ static console_command_entry_t console_commands[] = {
   { "player.set_vx", console_PlayerSetVX, CF_NEVER },
   { "player.set_vy", console_PlayerSetVY, CF_NEVER },
   { "player.set_vz", console_PlayerSetVZ, CF_NEVER },
+  { "player.kill", console_PlayerKill, CF_NEVER },
 
   { "music.restart", console_MusicRestart, CF_ALWAYS },
 
@@ -2438,6 +2457,12 @@ static console_command_entry_t console_commands[] = {
   { "iddit", console_BasicCheat, CF_DEMO },
   { "idclev", console_BasicCheat, CF_DEMO },
   { "idmus", console_BasicCheat, CF_DEMO },
+  { "idbeholdv", console_BasicCheat, CF_DEMO },
+  { "idbeholds", console_BasicCheat, CF_DEMO },
+  { "idbeholdi", console_BasicCheat, CF_DEMO },
+  { "idbeholdr", console_BasicCheat, CF_DEMO },
+  { "idbeholda", console_BasicCheat, CF_DEMO },
+  { "idbeholdl", console_BasicCheat, CF_DEMO },
 
   { "tntcomp", console_BasicCheat, CF_DEMO },
   { "tntem", console_BasicCheat, CF_DEMO },
@@ -2490,7 +2515,7 @@ static console_command_entry_t console_commands[] = {
 };
 
 static void dsda_AddConsoleMessage(const char* message) {
-  strncpy(console_message_entry, message, CONSOLE_ENTRY_SIZE);
+  strncpy(console_message_entry, message, CONSOLE_ENTRY_SIZE - 1);
 }
 
 static dboolean dsda_AuthorizeCommand(console_command_entry_t* entry) {
@@ -2577,12 +2602,14 @@ void dsda_UpdateConsoleText(char* text) {
     if (text[i] < 32 || text[i] > 126)
       continue;
 
-    for (shift_i = strlen(console_entry->text); shift_i > console_entry_index; --shift_i)
+    if (console_entry_index > CONSOLE_ENTRY_SIZE - 2)
+      console_entry_index = CONSOLE_ENTRY_SIZE - 2;
+
+    for (shift_i = strlen(console_entry->text) - 1; shift_i > console_entry_index; --shift_i)
       console_entry->text[shift_i] = console_entry->text[shift_i - 1];
 
     console_entry->text[console_entry_index] = tolower(text[i]);
-    if (console_entry_index < CONSOLE_ENTRY_SIZE)
-      ++console_entry_index;
+    ++console_entry_index;
   }
 
   dsda_UpdateConsoleDisplay();
