@@ -18,9 +18,8 @@
 #ifndef __DSDA_HUD_COMPONENT_KEYS__
 #define __DSDA_HUD_COMPONENT_KEYS__
 
-void dsda_InitKeysHC(int x_offset, int y_offset, int vpt_flags);
-void dsda_UpdateKeysHC(void);
-void dsda_DrawKeysHC(void);
-void dsda_EraseKeysHC(void);
+void dsda_InitKeysHC(int x_offset, int y_offset, int vpt_flags, int* args, int arg_count, void** data);
+void dsda_UpdateKeysHC(void* data);
+void dsda_DrawKeysHC(void* data);
 
 #endif
