@@ -18,9 +18,8 @@
 #ifndef __DSDA_HUD_COMPONENT_TRACKER__
 #define __DSDA_HUD_COMPONENT_TRACKER__
 
-void dsda_InitTrackerHC(int x_offset, int y_offset, int vpt_flags);
-void dsda_UpdateTrackerHC(void);
-void dsda_DrawTrackerHC(void);
-void dsda_EraseTrackerHC(void);
+void dsda_InitTrackerHC(int x_offset, int y_offset, int vpt_flags, int* args, int arg_count, void** data);
+void dsda_UpdateTrackerHC(void* data);
+void dsda_DrawTrackerHC(void* data);
 
 #endif
