@@ -285,19 +285,16 @@ void dsda_RemoveMobjThingID(mobj_t* mo);
 void P_IterateCompatibleSpecHit(mobj_t *thing, fixed_t oldx, fixed_t oldy);
 void P_IterateZDoomSpecHit(mobj_t *thing, fixed_t oldx, fixed_t oldy);
 
-static const map_format_t zdoom_in_hexen_map_format = {
+static const map_format_t zdoom_map_format = {
   .zdoom = true,
   .hexen = true,
   .polyobjs = true,
   .acs = false,
   .thing_id = true,
-  .mapinfo = false,
   .sndseq = false,
-  .sndinfo = false,
   .animdefs = false,
   .doublesky = false,
   .map99 = false,
-  .lax_monster_activation = true,
   .generalized_mask = ~0xff,
   .switch_activation = SPAC_USE | SPAC_IMPACT | SPAC_PUSH,
   .init_sector_special = P_SpawnZDoomSectorSpecial,
@@ -349,13 +346,10 @@ static const map_format_t hexen_map_format = {
   .polyobjs = true,
   .acs = true,
   .thing_id = true,
-  .mapinfo = true,
   .sndseq = true,
-  .sndinfo = true,
   .animdefs = true,
   .doublesky = true,
   .map99 = true,
-  .lax_monster_activation = false,
   .generalized_mask = 0, // not used
   .switch_activation = SPAC_USE | SPAC_IMPACT,
   .init_sector_special = NULL, // not used
@@ -407,13 +401,10 @@ static const map_format_t heretic_map_format = {
   .polyobjs = false,
   .acs = false,
   .thing_id = false,
-  .mapinfo = false,
   .sndseq = false,
-  .sndinfo = false,
   .animdefs = false,
   .doublesky = false,
   .map99 = false,
-  .lax_monster_activation = true,
   .generalized_mask = 0,
   .switch_activation = 0, // not used
   .init_sector_special = P_SpawnCompatibleSectorSpecial,
@@ -465,13 +456,10 @@ static const map_format_t doom_map_format = {
   .polyobjs = false,
   .acs = false,
   .thing_id = false,
-  .mapinfo = false,
   .sndseq = false,
-  .sndinfo = false,
   .animdefs = false,
   .doublesky = false,
   .map99 = false,
-  .lax_monster_activation = true,
   .generalized_mask = ~31,
   .switch_activation = 0, // not used
   .init_sector_special = P_SpawnCompatibleSectorSpecial,
@@ -525,7 +513,7 @@ static void dsda_ApplyMapPrecision(void) {
 }
 
 void dsda_ApplyZDoomMapFormat(void) {
-  map_format = zdoom_in_hexen_map_format;
+  map_format = zdoom_map_format;
 
   if (!mbf21)
     I_Error("You must use complevel 21 when playing doom-in-hexen format maps.");
@@ -542,9 +530,6 @@ void dsda_ApplyDefaultMapFormat(void) {
   else
     map_format = doom_map_format;
 
-  if (dsda_Flag(dsda_arg_mapinfo) && !map_format.mapinfo)
-    map_format.mapinfo = W_LumpNameExists("MAPINFO");
-
   dsda_ApplyMapPrecision();
   dsda_MigrateMobjInfo();
 }
