@@ -357,14 +357,14 @@ static inline int WRAP(int i, int w)
   return i % w;
 }
 
-int dsda_LegacyMapMusic(int* music_index, int* music_lump) {
+int dsda_LegacyMapMusic(int* music_index, int* music_lump, int episode, int map) {
   *music_lump = -1;
 
   if (idmusnum != -1)
     *music_index = idmusnum; //jff 3/17/98 reload IDMUS music if not -1
   else {
     if (gamemode == commercial)
-      *music_index = mus_runnin + WRAP(gamemap - 1, DOOM_MUSINFO - mus_runnin);
+      *music_index = mus_runnin + WRAP(map - 1, DOOM_MUSINFO - mus_runnin);
     else {
       static const int spmus[] = {
         mus_e3m4,
@@ -380,13 +380,13 @@ int dsda_LegacyMapMusic(int* music_index, int* music_lump) {
 
       if (heretic)
         *music_index = heretic_mus_e1m1 +
-                       WRAP((gameepisode - 1) * 9 + gamemap - 1,
+                       WRAP((episode - 1) * 9 + map - 1,
                             HERETIC_NUMMUSIC - heretic_mus_e1m1);
-      else if (gameepisode < 4)
+      else if (episode < 4)
         *music_index = mus_e1m1 +
-                       WRAP((gameepisode - 1) * 9 + gamemap - 1, mus_runnin - mus_e1m1);
+                       WRAP((episode - 1) * 9 + map - 1, mus_runnin - mus_e1m1);
       else
-        *music_index = spmus[WRAP(gamemap - 1, 9)];
+        *music_index = spmus[WRAP(map - 1, 9)];
     }
   }
 
