@@ -44,11 +44,13 @@ typedef struct playpal_data_s {
   int transparent;
   int duplicate;
   int black;
+  int white;
 
   // Array of SDL_Color structs used for setting the 256-colour palette
   SDL_Color* colours;
 } dsda_playpal_t;
 
+double dsda_PaletteEntryLightness(const char *playpal, int i);
 dsda_playpal_t* dsda_PlayPalData(void);
 void dsda_CyclePlayPal(void);
 void dsda_SetPlayPal(int index);
