@@ -121,6 +121,9 @@ extern const char * comp_lev_str[];
 extern int shorttics;
 extern int longtics;
 
+// Allows use of HELP2 screen for PWADs under DOOM 1
+extern int pwad_help2_check;
+
 // hexen
 
 void G_Completed(int map, int position, int flags, angle_t angle);
