@@ -282,7 +282,7 @@ void gld_MapDrawSubsectors(player_t *plr, int fx, int fy, fixed_t mx, fixed_t my
   float coord_scale;
   GLTexture *gltexture;
 
-  alpha = (float)(automap_overlay ? map_textured_overlay_trans : map_textured_trans) / 100.0f;
+  alpha = (float)((automap_overlay > 0) ? map_textured_overlay_trans : map_textured_trans) / 100.0f;
   if (alpha == 0)
     return;
 
@@ -714,7 +714,7 @@ void gld_DrawLine_f(float x0, float y0, float x1, float y1, int BaseColor)
   unsigned char a;
   map_line_t *line;
 
-  a = (automap_overlay ? map_lines_overlay_trans * 255 / 100 : 255);
+  a = ((automap_overlay == 1) ? map_lines_overlay_trans * 255 / 100 : 255);
   if (a == 0)
     return;
 
@@ -848,6 +848,36 @@ void gld_FillBlock(int x, int y, int width, int height, int col)
   glsl_PopNullShader();
 }
 
+void gld_DrawShaded(int x, int y, int width, int height, int shade)
+{
+  // This is more messy than I'd like. (I hate this, but this is my current fix for the menu overlay invert)
+  // The `col` fixes the menu overlay from inverting during `invul_cm`.
+  // The 'automap` boolean is to undo the `col` invert for the automap.
+  dboolean automap = V_IsAutomapLightmodeIndexed();
+  int col = invul_cm && !automap ? playpal_white : playpal_black;
+  color_rgb_t color = gld_LookupIndexedColor(col, V_IsUILightmodeIndexed() || V_IsAutomapLightmodeIndexed());
+
+  glsl_PushNullShader();
+
+  gld_EnableTexture2D(GL_TEXTURE0_ARB, false);
+
+  glColor4f((float)color.r/255.0f,
+            (float)color.g/255.0f,
+            (float)color.b/255.0f,
+            (float)shade/30);
+
+  glBegin(GL_TRIANGLE_STRIP);
+    glVertex2i( x, y );
+    glVertex2i( x, y+height );
+    glVertex2i( x+width, y );
+    glVertex2i( x+width, y+height );
+  glEnd();
+  glColor4f(1.0f,1.0f,1.0f,1.0f);
+  gld_EnableTexture2D(GL_TEXTURE0_ARB, true);
+
+  glsl_PopNullShader();
+}
+
 void gld_SetPalette(int palette)
 {
   static int last_palette = 0;
