@@ -1927,7 +1927,7 @@ void P_ArchiveSounds(void)
 
     if (i == po_NumPolyobjs)
     {                       // Sound is attached to a sector, not a polyobj
-      sec = R_PointInSubsector(node->mobj->x, node->mobj->y)->sector;
+      sec = R_PointInSector(node->mobj->x, node->mobj->y);
       difference = (int) (sec - sectors);
       P_SAVE_BYTE(0);   // 0 -- sector sound origin
     }
