@@ -165,6 +165,8 @@ const void* W_LockLumpNum(int lump);
 int W_LumpNumExists(int lump);
 int W_LumpNameExists(const char *name);
 int W_LumpNameExists2(const char *name, int ns);
+int W_PWADLumpNumExists(int lump);
+int W_PWADLumpNameExists(const char *name);
 
 // CPhipps - convenience macros
 //#define W_LumpByNum(num) (W_LumpByNum)((num),1)
