@@ -412,6 +412,42 @@ void WI_levelNameLump(int epis, int map, char* buf)
   }
 }
 
+static int WI_killPercent(int i)
+{
+  return wbs->maxkills ? (plrs[i].skills * 100) / wbs->maxkills
+                       : MAX(1, plrs[i].skills) * 100;
+}
+
+static int WI_killLimit(int i)
+{
+  return wbs->maxkills ? (plrs[i].skills * 100) / wbs->maxkills
+                       : (plrs[i].skills * 100);
+
+}
+
+static int WI_itemPercent(int i)
+{
+  return wbs->maxitems ? (plrs[i].sitems * 100) / wbs->maxitems : 100;
+}
+
+static int WI_itemLimit(int i)
+{
+  return wbs->maxitems ? (plrs[i].sitems * 100) / wbs->maxitems
+                       : (plrs[i].sitems * 100);
+
+}
+
+static int WI_secretPercent(int i)
+{
+  return wbs->maxsecret ? (plrs[i].ssecret * 100) / wbs->maxsecret : 100;
+}
+
+static int WI_secretLimit(int i)
+{
+  return wbs->maxsecret ? (plrs[i].ssecret * 100) / wbs->maxsecret
+                        : compatibility_level < lxdoom_1_compatibility ? 0 : 100;
+}
+
 // ====================================================================
 // WI_slamBackground
 // Purpose: Put the full-screen background up prior to patches
@@ -430,7 +466,7 @@ static void WI_slamBackground(void)
     snprintf(name, sizeof(name), "WIMAP%d", wbs->epsd);
 
   // e6y: wide-res
-  V_FillBorder(-1, 0);
+  V_ClearBorder();
 
   // background
   V_DrawNamePatch(0, 0, FB, name, CR_DEFAULT, VPT_STRETCH);
@@ -498,13 +534,8 @@ void WI_drawLF(void)
   {
     // The level defines a new name but no texture for the name.
     WI_DrawString(160, y, lf_levelname);
-    y += (5 * hud_font.height / 4);
 
-    if (lf_author)
-    {
-      WI_DrawString(160, y, lf_author);
-      y += (5 * hud_font.height / 4);
-    }
+    y += (5 * hud_font.height / 4);
   }
   else
   {
@@ -522,12 +553,18 @@ void WI_drawLF(void)
     V_DrawNamePatch((320 - V_NamePatchWidth(lname)) / 2, y,
       FB, lname, CR_DEFAULT, VPT_STRETCH);
 
-    // draw "Finished!"
     y += (5 * V_NamePatchHeight(lname)) / 4;
   }
 
+  if (lf_author)
+  {
+    WI_DrawString(160, y, lf_author);
+
+    y += (5 * hud_font.height / 4);
+  }
 
   // CPhipps - patch drawing updated
+  // draw "Finished!"
   V_DrawNamePatch((320 - V_NamePatchWidth(finished))/2, y,
      FB, finished, CR_DEFAULT, VPT_STRETCH);
 }
@@ -553,21 +590,16 @@ void WI_drawEL(void)
   V_DrawNamePatch((320 - V_NamePatchWidth(entering)) / 2,
     y, FB, entering, CR_DEFAULT, VPT_STRETCH);
 
+  y += (5 * V_NamePatchHeight(entering)) / 4;
 
   dsda_PrepareEntering();
 
   if (el_levelname)
   {
-    y += (5 * V_NamePatchHeight(entering)) / 4;
-
     // The level defines a new name but no texture for the name.
     WI_DrawString(160, y, el_levelname);
 
-    if (el_author)
-    {
-      y += (5 * hud_font.height / 4);
-      WI_DrawString(160, y, el_author);
-    }
+    y += (5 * hud_font.height / 4);
   }
   else
   {
@@ -580,12 +612,23 @@ void WI_drawEL(void)
     if (!W_LumpNameExists(lname))
       return;
 
-    // draw level
-    y += (5 * V_NamePatchHeight(lname)) / 4;
+    // fullscreen cwilv graphic
+    if (V_NamePatchHeight(lname) == 200)
+      y = WI_TITLEY;
 
     // CPhipps - patch drawing updated
+    // draw level
     V_DrawNamePatch((320 - V_NamePatchWidth(lname)) / 2, y, FB,
       lname, CR_DEFAULT, VPT_STRETCH);
+
+    y += (5 * V_NamePatchHeight(lname)) / 4;
+  }
+
+  if (el_author)
+  {
+    WI_DrawString(160, y, el_author);
+
+    y += (5 * hud_font.height / 4);
   }
 }
 
@@ -951,7 +994,7 @@ static void WI_drawTimeStats(int cnt_time, int cnt_total_time, int cnt_par)
 
   if (
     !(modifiedgame && !wbs->modified_partime)
-    || (gamemission == pack_nerve && singleplayer)
+    || (gamemission == pack_nerve && allow_incompatibility)
   )
   {
     if (wbs->epsd < 4 || wbs->modified_partime)
@@ -1110,7 +1153,7 @@ void WI_drawShowNextLoc(void)
       WI_drawOnLnode(wbs->next, yah);
   }
 
-  if (gamemission == pack_nerve && singleplayer && wbs->last == 7)
+  if (gamemission == pack_nerve && allow_incompatibility && wbs->last == 7)
     return; // MAP08 end game
 
   // draws which level you are entering..
@@ -1408,23 +1451,6 @@ void WI_drawDeathmatchStats(void)
 // Note: The term "Netgame" means a coop game
 //
 
-// e6y
-// 'short' => 'int' for cnt_kills, cnt_items and cnt_secret
-//
-// Original sources use 'int' type for cnt_kills instead of 'short'
-// I don't know who have made change of type, but this change
-// leads to desynch  if 'kills' percentage is more than 32767.
-// Actually PrBoom will be in an infinite cycle at calculation of
-// percentage if the player will not press <Use> for acceleration, because
-// the condition (cnt_kills[0] >= (plrs[me].skills * 100) / wbs->maxkills)
-// will be always false in this case.
-//
-// If you will kill 800 monsters on MAP30 on Ultra-Violence skill and
-// will not press <Use>, vanilla will count up to 80000%, but PrBoom
-// will be in infinite cycle of counting:
-// (0, 1, 2, ..., 32766, 32767, -32768, -32767, ..., -1, 0, 1, ...)
-// Negative numbers will not be displayed.
-
 static int *cnt_kills;
 static int *cnt_items;
 static int *cnt_secret;
@@ -1503,12 +1529,10 @@ void WI_updateNetgameStats(void)
       if (!playeringame[i])
         continue;
 
-      cnt_kills[i] = (plrs[i].skills * 100) / wbs->maxkills;
-      cnt_items[i] = (plrs[i].sitems * 100) / wbs->maxitems;
+      cnt_kills[i] = WI_killPercent(i);
+      cnt_items[i] = WI_itemPercent(i);
+      cnt_secret[i] = WI_secretPercent(i);
 
-      // killough 2/22/98: Make secrets = 100% if maxsecret = 0:
-      cnt_secret[i] = wbs->maxsecret ?
-                      (plrs[i].ssecret * 100) / wbs->maxsecret : 100;
       if (dofrags)
         cnt_frags[i] = WI_fragSum(i);  // we had frags
     }
@@ -1530,8 +1554,8 @@ void WI_updateNetgameStats(void)
 
       cnt_kills[i] += 2;
 
-      if (cnt_kills[i] >= (plrs[i].skills * 100) / wbs->maxkills)
-        cnt_kills[i] = (plrs[i].skills * 100) / wbs->maxkills;
+      if (cnt_kills[i] >= WI_killLimit(i))
+        cnt_kills[i] = WI_killPercent(i);
       else
         stillticking = true; // still got stuff to tally
     }
@@ -1555,8 +1579,8 @@ void WI_updateNetgameStats(void)
         continue;
 
       cnt_items[i] += 2;
-      if (cnt_items[i] >= (plrs[i].sitems * 100) / wbs->maxitems)
-        cnt_items[i] = (plrs[i].sitems * 100) / wbs->maxitems;
+      if (cnt_items[i] >= WI_itemLimit(i))
+        cnt_items[i] = WI_itemPercent(i);
       else
         stillticking = true;
     }
@@ -1581,10 +1605,8 @@ void WI_updateNetgameStats(void)
 
       cnt_secret[i] += 2;
 
-      // killough 2/22/98: Make secrets = 100% if maxsecret = 0:
-
-      if (cnt_secret[i] >= (wbs->maxsecret ? (plrs[i].ssecret * 100) / wbs->maxsecret : compatibility_level < lxdoom_1_compatibility ? 0 : 100))
-        cnt_secret[i] = wbs->maxsecret ? (plrs[i].ssecret * 100) / wbs->maxsecret : 100;
+      if (cnt_secret[i] >= WI_secretLimit(i))
+        cnt_secret[i] = WI_secretPercent(i);
       else
         stillticking = true;
     }
@@ -1761,12 +1783,9 @@ void WI_updateStats(void)
   if (acceleratestage && sp_state != 10)
   {
     acceleratestage = 0;
-    cnt_kills[0] = (plrs[me].skills * 100) / wbs->maxkills;
-    cnt_items[0] = (plrs[me].sitems * 100) / wbs->maxitems;
-
-    // killough 2/22/98: Make secrets = 100% if maxsecret = 0:
-    cnt_secret[0] = (wbs->maxsecret ?
-      (plrs[me].ssecret * 100) / wbs->maxsecret : 100);
+    cnt_kills[0] = WI_killPercent(me);
+    cnt_items[0] = WI_itemPercent(me);
+    cnt_secret[0] = WI_secretPercent(me);
 
     cnt_total_time = wbs->totaltimes / TICRATE;
     cnt_time = plrs[me].stime / TICRATE;
@@ -1782,9 +1801,9 @@ void WI_updateStats(void)
     if (!(bcnt&3))
       S_StartVoidSound(sfx_pistol);
 
-    if (cnt_kills[0] >= (plrs[me].skills * 100) / wbs->maxkills)
+    if (cnt_kills[0] >= WI_killLimit(me))
     {
-      cnt_kills[0] = (plrs[me].skills * 100) / wbs->maxkills;
+      cnt_kills[0] = WI_killPercent(me);
       S_StartVoidSound(sfx_barexp);
       sp_state++;
     }
@@ -1796,9 +1815,9 @@ void WI_updateStats(void)
     if (!(bcnt&3))
       S_StartVoidSound(sfx_pistol);
 
-    if (cnt_items[0] >= (plrs[me].sitems * 100) / wbs->maxitems)
+    if (cnt_items[0] >= WI_itemLimit(me))
     {
-      cnt_items[0] = (plrs[me].sitems * 100) / wbs->maxitems;
+      cnt_items[0] = WI_itemPercent(me);
       S_StartVoidSound(sfx_barexp);
       sp_state++;
     }
@@ -1810,13 +1829,9 @@ void WI_updateStats(void)
     if (!(bcnt&3))
       S_StartVoidSound(sfx_pistol);
 
-    // killough 2/22/98: Make secrets = 100% if maxsecret = 0:
-    if ((!wbs->maxsecret && compatibility_level < lxdoom_1_compatibility) ||
-  cnt_secret[0] >= (wbs->maxsecret ?
-      (plrs[me].ssecret * 100) / wbs->maxsecret : 100))
+    if (cnt_secret[0] >= WI_secretLimit(me))
     {
-      cnt_secret[0] = (wbs->maxsecret ?
-        (plrs[me].ssecret * 100) / wbs->maxsecret : 100);
+      cnt_secret[0] = WI_secretPercent(me);
       S_StartVoidSound(sfx_barexp);
       sp_state++;
     }
@@ -1987,11 +2002,19 @@ void WI_Ticker(void)
 
   if (bcnt == 1)
   {
-    // intermission music
-    if ( gamemode == commercial )
-      S_ChangeMusic(mus_dm2int, true);
+    int mnum;
+    int muslump;
+
+    dsda_IntermissionMusic(&mnum, &muslump);
+
+    if (muslump >= 0)
+    {
+      S_ChangeMusInfoMusic(muslump, true);
+    }
     else
-      S_ChangeMusic(mus_inter, true);
+    {
+      S_ChangeMusic(mnum, true);
+    }
   }
 
   WI_checkForAccelerate();
@@ -2137,12 +2160,6 @@ void WI_initVariables(wbstartstruct_t* wbstartstruct)
   me = wbs->pnum;
   plrs = wbs->plyr;
 
-  if (!wbs->maxkills)
-    wbs->maxkills = 1;  // probably only useful in MAP30
-
-  if (!wbs->maxitems)
-    wbs->maxitems = 1;
-
   if ( gamemode != retail )
     if (wbs->epsd > 2)
       wbs->epsd -= 3;
